exec("".join(map(chr,[int("".join(str({'ಅ': 0,
 'ಅ:': 14,
 'ಅಂ': 13,
 'ಆ': 1,
 'ಇ': 2,
 'ಈ': 3,
 'ಉ': 4,
 'ಊ': 5,
 'ಋ': 6,
 'ಎ': 7,
 'ಏ': 8,
 'ಐ': 9,
 'ಒ': 10,
 'ಓ': 11,
 'ಔ': 12,
 'ಕ': 15,
 'ಖ': 16,
 'ಗ': 17,
 'ಘ': 18,
 'ಙ': 19,
 'ಚ': 20,
 'ಛ': 21,
 'ಜ': 22,
 'ಝ': 23,
 'ಞ': 24,
 'ಟ': 25,
 'ಠ': 26,
 'ಡ': 27,
 'ಢ': 28,
 'ಣ': 29,
 'ತ': 30,
 'ಥ': 31,
 'ದ': 32,
 'ಧ': 33,
 'ನ': 34,
 'ಪ': 35,
 'ಫ': 36,
 'ಬ': 37,
 'ಭ': 38,
 'ಮ': 39,
 'ಯ': 40,
 'ರ': 41,
 'ಲ': 42,
 'ಳ': 48,
 'ವ': 43,
 'ಶ': 44,
 'ಷ': 45,
 'ಸ': 46,
 'ಹ': 47}[i]) for i in x.split())) for x in
"ಈ ಊ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಉ ಎ  ಐ ಐ  \
ಆ ಅ ಏ  ಆ ಅ ಊ  ಉ ಋ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಆ ಅ  ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಆ \
ಉ  ಆ ಆ ಋ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಅ\
  ಆ ಅ ಇ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಈ ಇ  ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಈ ಇ \
 ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಆ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ\
 ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಅ  ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ \
ಆ ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಇ ಆ  ಆ ಆ ಊ  ಆ ಅ  ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಅ ಇ  ಈ\
 ಇ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ ಅ  ಉ ಆ  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  \
ಈ ಉ  ಈ ಉ  ಈ ಉ  ಋ ಎ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಉ ಊ  ಆ ಅ ಏ\
  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಅ ಇ  \
ಐ ಎ  ಐ ಐ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ\
 ಇ  ಆ ಆ ಆ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ \
ಆ ಅ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಆ  ಆ ಆ ಆ  ಆ ಅ ಏ  ಉ ಋ  ಈ ಉ  ಈ ಉ  ಈ ಉ  ಆ ಅ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಐ \
ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಉ ಋ  ಋ ಊ  ಆ ಆ ಉ  ಆ ಅ\
 ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಏ ಅ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  \
ಆ ಆ ಉ  ಉ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ ಆ \
 ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಈ ಉ\
  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಇ  ಉ ಊ  ಈ ಇ\
  ಎ ಐ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಇ ಆ  ಆ\
 ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  \
ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ \
ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಈ ಇ  ಆ ಅ ಏ  ಆ \
ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಉ ಋ  ಈ ಇ  ಎ ಅ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ\
 ಇ  ಆ ಅ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಏ  ಆ ಅ ಊ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ ಋ\
  ಈ ಇ  ಈ ಐ  ಆ ಅ ಉ  ಆ ಆ ಋ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಊ ಏ  ಉ ಎ  ಉ ಎ  ಆ ಅ ಈ  ಆ ಅ ಊ  ಆ\
 ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಐ ಏ  ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಉ ಎ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ \
ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಊ ಈ  ಉ ಏ  ಉ ಎ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  \
ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಈ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಉ ಆ  ಆ ಅ \
 ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಋ ಊ  ಆ ಅ ಅ  ಆ ಅ ಅ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಉ\
  ಆ ಅ ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಆ ಆ ಊ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಉ ಋ  ಐ ಎ  ಆ ಅ ಅ  ಆ ಅ ಅ  \
ಐ ಊ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ  ಉ\
 ಊ  ಆ ಅ ಊ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಉ ಊ  ಉ ಊ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ\
 ಆ ಋ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  \
ಆ ಅ ಅ  ಋ ಆ  ಏ ಉ  ಆ ಆ ಉ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ\
 ಆ ಇ  ಋ ಆ  ಈ ಉ  ಎ ಈ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ \
ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಈ\
 ಇ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ\
  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಉ ಋ  ಐ ಎ  ಆ ಅ ಅ  ಆ ಅ ಅ  ಐ ಊ  ಐ ಎ  ಆ\
 ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ  ಉ ಊ  ಆ ಆ ಆ  \
ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಉ ಊ  ಉ ಊ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ\
  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಅ \
ಅ  ಋ ಆ  ಏ ಉ  ಆ ಆ ಉ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ ಆ ಇ\
  ಋ ಆ  ಈ ಉ  ಎ ಐ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ\
 ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ\
  ಈ ಇ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ \
ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಉ ಋ  ಐ ಎ  ಆ ಅ ಅ  ಆ ಅ ಅ  ಐ ಊ  ಐ ಎ\
  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ  ಉ ಊ  ಆ ಆ \
ಏ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಉ ಊ  ಉ ಊ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ \
ಆ ಆ  ಆ ಆ ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  \
ಈ ಉ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಆ\
 ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಈ ಉ  ಎ ಊ  ಐ ಎ  ಆ \
ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಇ  ಉ ಐ  ಉ ಋ  ಉ ಏ  ಉ ಋ  ಊ \
ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ ಆ ಇ  ಋ ಆ  ಈ ಉ  ಏ ಈ  ಆ ಅ ಉ  ಆ \
ಆ ಆ  ಆ ಆ ಐ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ \
 ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಅ ಇ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  \
ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಊ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ \
ಅ ಆ  ಆ ಆ ಉ  ಉ ಋ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಐ ಊ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ\
 ಈ  ಆ ಆ ಊ  ಉ ಅ  ಉ ಆ  ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಇ ಆ\
  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಆ  ಐ ಏ  ಆ ಅ ಇ \
 ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಉ ಅ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಊ  \
ಉ ಋ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಉ ಉ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ\
 ಆ ಊ  ಉ ಋ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಇ ಅ  ಐ ಐ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಈ ಇ  ಎ ಅ  ಆ ಅ ಊ  \
ಆ ಅ ಏ  ಆ ಅ ಆ  ಎ ಏ  ಆ ಆ ಆ  ಆ ಆ ಋ  ಎ ಅ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಋ ಐ \
 ಆ ಆ ಉ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಆ  ಊ ಏ  ಆ ಅ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ \
ಋ  ಉ ಅ  ಆ ಅ ಇ  ಈ ಉ  ಐ ಆ  ಆ ಅ ಅ ಋ ಅ  ಐ ಈ  ಈ ಇ  ಋ ಐ  ಆ ಆ ಉ  ಆ ಆ ಉ  ಆ ಆ ಆ\
  ಆ ಆ ಉ  ಊ ಏ  ಈ ಇ  ಆ ಇ ಈ  ಆ ಅ ಆ  ಆ ಇ ಊ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಆ ಅ  ಆ ಅ ಊ  ಆ ಅ\
 ಇ  ಈ ಇ  ಐ ಊ  ಐ ಊ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಐ ಊ  ಐ ಊ  ಈ ಇ  ಋ ಆ  ಋ ಆ  \
ಈ ಇ  ಈ ಉ  ಐ ಊ  ಐ ಊ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಐ ಊ  ಈ ಉ  ಊ ಏ  ಆ ಅ \
 ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ ಅ  ಉ ಆ  ಆ ಅ"
.split("  ")])))
