exec("".join(map(chr,[int("".join(str({'ಅ': 0,
 'ಅ:': 14,
 'ಅಂ': 13,
 'ಆ': 1,
 'ಇ': 2,
 'ಈ': 3,
 'ಉ': 4,
 'ಊ': 5,
 'ಋ': 6,
 'ಎ': 7,
 'ಏ': 8,
 'ಐ': 9,
 'ಒ': 10,
 'ಓ': 11,
 'ಔ': 12,
 'ಕ': 15,
 'ಖ': 16,
 'ಗ': 17,
 'ಘ': 18,
 'ಙ': 19,
 'ಚ': 20,
 'ಛ': 21,
 'ಜ': 22,
 'ಝ': 23,
 'ಞ': 24,
 'ಟ': 25,
 'ಠ': 26,
 'ಡ': 27,
 'ಢ': 28,
 'ಣ': 29,
 'ತ': 30,
 'ಥ': 31,
 'ದ': 32,
 'ಧ': 33,
 'ನ': 34,
 'ಪ': 35,
 'ಫ': 36,
 'ಬ': 37,
 'ಭ': 38,
 'ಮ': 39,
 'ಯ': 40,
 'ರ': 41,
 'ಲ': 42,
 'ಳ': 48,
 'ವ': 43,
 'ಶ': 44,
 'ಷ': 45,
 'ಸ': 46,
 'ಹ': 47}[i]) for i in x.split())) for x in
"ಆ ಅ ಇ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಎ  ಆ ಆ ಇ  ಆ \
ಆ ಋ  ಆ ಆ ಆ  ಆ ಆ ಆ  ಆ ಅ ಏ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಆ \
ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಎ  ಆ ಆ ಇ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಅ\
 ಊ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಐ ಊ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ ಆ \
ಊ  ಆ ಅ  ಆ ಅ  ಆ ಆ ಐ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ\
 ಅ  ಉ ಅ  ಈ ಐ  ಏ ಇ  ಋ ಐ  ಋ ಊ  ಋ ಏ  ಎ ಎ  ಋ ಐ  ಉ ಋ  ಆ ಅ ಐ  ಆ ಅ ಅ  ಈ ಐ  ಉ \
ಉ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಋ ಆ  ಈ ಐ\
  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಅ ಇ  ಉ ಊ  ಊ ಋ  ಈ ಐ  ಉ ಆ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಇ\
  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಐ ಊ  ಆ ಅ ಅ\
  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  \
ಈ ಇ  ಋ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಉ ಋ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಐ ಎ  ಆ ಅ ಅ  ಉ ಅ  ಉ ಆ  ಆ ಅ  ಆ \
ಅ  ಆ ಅ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಎ  ಆ ಆ ಇ  ಉ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ \
ಇ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಋ ಆ  ಈ ಐ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ \
ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಏ  ಆ ಅ \
ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಈ ಐ  ಉ ಐ  ಉ ಋ  ಉ ಏ  ಉ ಋ  ಊ \
ಅ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ \
 ಆ ಆ ಉ  ಋ ಆ  ಈ ಐ  ಎ ಎ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಎ ಆ  ಆ ಆ ಆ  \
ಆ ಆ ಐ  ಆ ಅ ಅ  ಐ ಎ  ಉ ಋ  ಋ ಋ  ಉ ಉ  ಈ ಇ  ಎ ಎ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಏ  ಐ ಎ  ಆ \
ಆ ಅ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಉ ಋ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಎ \
 ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಐ ಊ  ಆ ಅ ಆ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಋ ಆ\
  ಈ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಆ  ಆ ಆ ಐ  \
ಆ ಅ ಅ  ಐ ಎ  ಉ ಋ  ಐ ಏ  ಊ ಊ  ಊ ಇ  ಉ ಐ  ಉ ಐ  ಋ ಉ  ಆ ಅ ಈ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ \
ಊ  ಆ ಅ ಏ  ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಉ ಉ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಇ  ಆ ಆ ಇ  ಆ ಆ ಎ  \
ಆ ಅ ಎ  ಐ ಎ  ಉ ಐ  ಊ ಇ  ಊ ಆ  ಉ ಐ  ಋ ಉ  ಆ ಅ ಈ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಅ ಏ  \
ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ \
ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಈ\
 ಐ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಎ \
ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಐ ಊ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  \
ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ \
ಅ ಈ  ಐ ಊ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ \
 ಆ ಆ ಆ  ಆ ಆ ಅ  ಉ ಉ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಎ ಈ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಅ ಏ  ಆ ಆ ಎ \
 ಆ ಅ ಅ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ\
 ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಅ ಇ  \
ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಈ ಇ  ಏ ಇ  ಋ ಐ  ಋ ಊ  ಋ ಏ  ಎ ಎ  ಋ ಐ  ಆ ಅ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಐ ಊ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  \
ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಐ ಊ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಆ \
ಅ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಆ ಋ  ಆ ಇ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಋ ಆ  ಈ\
 ಐ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಇ ಅ  ಆ ಆ ಋ  ಉ ಎ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಎ  ಆ ಅ ಅ  \
ಆ ಆ ಆ  ಆ ಆ ಐ  ಆ ಆ ಅ  ಈ ಐ  ಉ ಉ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಏ ಈ  ಆ ಆ ಇ  ಆ ಅ ಆ  \
ಐ ಐ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ \
 ಆ ಆ ಉ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ\
  ಈ ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ \
ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  \
ಆ ಆ ಎ  ಆ ಆ ಉ  ಆ ಅ ಏ  ಋ ಆ  ಈ ಐ  ಆ ಅ ಉ  ಆ ಆ ಋ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಊ  ಊ ಏ \
 ಉ ಎ  ಉ ಎ  ಆ ಅ ಈ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಐ ಏ  ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ \
ಅ ಐ  ಉ ಎ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಊ ಈ  ಉ ಏ  ಉ ಎ  ಎ ಊ\
  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಉ ಉ  ಈ ಇ  ಈ ಇ\
  ಈ ಊ  ಈ ಇ  ಏ ಇ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಆ ಅ ಏ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಐ  ಆ ಅ\
 ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಈ ಇ  ಆ ಇ ಆ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಆ ಉ  \
ಆ ಆ ಆ  ಆ ಅ ಋ  ಆ ಅ ಆ  ಐ ಐ  ಆ ಆ ಋ  ಈ ಇ  ಏ ಊ  ಏ ಇ  ಎ ಋ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಋ ಆ  ಆ ಅ ಇ  \
ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಐ ಊ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ\
 ಆ ಊ  ಉ ಅ  ಉ ಆ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಆ ಆ\
 ಉ  ಆ ಇ ಆ  ಐ ಊ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಆ ಆ ಊ  ಋ ಆ  ಆ ಇ ಈ  \
ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ\
 ಆ ಊ  ಆ ಆ ಆ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಐ ಊ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ\
  ಆ ಆ ಊ  ಈ ಐ  ಊ ಏ  ಈ ಇ  ಐ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  \
ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  \
ಆ ಅ ಇ  ಆ ಇ ಆ  ಉ ಋ  ಐ ಊ  ಐ ಊ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಐ ಊ  ಊ ಏ  \
ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಐ ಈ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಇ ಊ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಐ ಊ  ಆ ಆ ಉ  ಆ ಅ\
 ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಋ ಆ  ಈ ಐ  ಋ ಇ  ಋ ಆ  ಊ ಆ \
 ಉ ಋ  ಊ ಉ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಊ  ಆ ಆ\
 ಋ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಅ ಏ  ಐ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  \
ಆ ಅ ಆ  ಆ ಆ ಊ  ಋ ಆ  ಐ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಊ  ಈ ಇ  ಎ ಋ  ಆ ಅ ಊ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಇ ಆ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ \
ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಆ ಆ ಇ \
 ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಆ ಉ  \
ಆ ಅ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಋ ಐ  ಆ ಇ\
 ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ\
  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಐ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಆ\
 ಆ ಋ  ಆ ಆ ಊ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ \
ಊ  ಈ ಇ  ಈ ಐ  ಆ ಆ ಅ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಈ ಐ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ\
 ಅ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಈ  ಉ ಉ  ಆ ಅ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಐ  ಆ ಅ ಏ  ಐ ಎ  ಆ ಆ ಊ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ \
ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಋ ಆ  ಐ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಈ ಐ  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ \
ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ\
  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ\
  ಈ ಇ  ಊ ಆ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ\
  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ \
ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ  ಊ ಏ  \
ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  \
ಊ ಆ  ಉ ಋ  ಊ ಉ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  \
ಈ ಐ  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ ಅ \
 ಆ ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ  ಊ \
ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ \
ಇ  ಊ ಆ  ಉ ಋ  ಊ ಊ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ \
ಇ  ಈ ಐ  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ\
 ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ \
 ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ \
 ಈ ಇ  ಊ ಆ  ಉ ಋ  ಊ ಋ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಈ ಐ  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  \
ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ\
 ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ\
 ಏ  ಈ ಇ  ಊ ಆ  ಉ ಋ  ಊ ಎ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಈ ಇ  ಈ ಐ  ಎ ಋ  ಆ ಅ ಊ  ಐ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಈ ಇ  ಊ ಏ  ಊ\
 ಏ  ಈ ಇ  ಎ ಐ  ಏ ಈ  ಎ ಈ  ಈ ಇ  ಋ ಊ  ಆ ಆ ಇ  ಆ ಆ ಇ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಆ ಏ  ಆ\
 ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಎ ಎ  ಎ ಈ  ಏ ಉ  ಈ ಇ  ಎ ಋ  ಆ ಅ ಊ  ಐ ಐ  \
ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಈ ಐ  ಉ ಉ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಋ ಎ  ಆ ಅ ಉ  \
ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಈ\
 ಇ  ಆ ಇ ಆ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಅ ಊ  ಐ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  \
ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಎ ಐ  ಆ\
 ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಏ ಈ  ಆ ಇ ಆ  \
ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಅ ಐ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಎ ಐ  ಏ ಈ  ಈ ಇ  ಎ ಈ  ಆ \
ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಈ \
ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಎ ಈ  ಆ ಆ ಅ  \
ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಋ ಊ  ಆ ಆ ಎ  ಆ ಅ ಅ  ಆ ಅ \
ಊ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಅ ಆ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಋ ಏ  ಆ ಅ ಆ  ಆ ಆ ಏ  ಆ \
ಅ ಆ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ\
  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಏ ಉ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಊ  ಐ ಐ  ಈ \
ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಈ  ಆ ಆ ಆ  ಆ ಅ ಇ  ಆ ಆ ಋ  ಆ ಆ ಐ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಆ  \
ಈ ಇ  ಋ ಏ  ಆ ಅ ಆ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ \
ಅ  ಆ ಆ ಋ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಎ ಋ  ಆ ಅ ಊ  ಐ ಏ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ \
ಊ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  \
ಆ ಆ ಅ  ಈ ಇ  ಎ ಎ  ಆ ಆ ಆ  ಆ ಅ ಅ  ಆ ಆ ಎ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಈ ಐ  ಉ ಉ  ಆ\
 ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಈ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಎ  ಆ ಅ \
ಆ  ಆ ಇ ಆ  ಆ ಆ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಅ  ಆ ಆ ಊ  ಋ ಆ  ಈ ಐ  ಏ ಉ  ಆ ಅ ಉ  ಆ ಅ\
 ಊ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಏ ಅ  ಆ ಇ \
ಆ  ಏ ಅ  ಆ ಅ ಊ  ಈ ಇ  ಎ ಎ  ಆ ಆ ಆ  ಆ ಅ ಅ  ಆ ಆ ಎ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಐ\
  ಆ ಅ ಉ  ಆ ಅ ಊ  ಐ ಐ  ಆ ಅ ಉ  ಈ ಇ  ಆ ಅ ಈ  ಆ ಅ ಊ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ \
ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಆ  ಈ\
 ಇ  ಎ ಐ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಈ ಇ  ಏ ಉ  ಆ\
 ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಅ ಊ  \
ಆ ಆ ಅ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಈ ಐ  ಉ ಉ  ಈ ಇ  ಈ \
ಇ  ಈ ಊ  ಈ ಇ  ಎ ಊ  ಆ ಅ ಆ  ಆ ಇ ಆ  ಆ ಆ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಅ  ಆ ಆ ಊ  ಈ ಇ\
  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ \
 ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಐ \
 ಆ ಅ ಏ  ಆ ಆ ಎ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಐ ಊ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  \
ಆ ಅ ಆ  ಐ ಊ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಆ ಋ  ಐ ಎ  ಋ ಆ  ಏ ಉ  ಆ ಆ ಉ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಉ ಉ\
  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಎ ಈ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಅ ಏ  ಆ ಆ ಎ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಈ ಇ\
  ಆ ಆ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  \
ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಐ ಐ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಆ  ಆ ಅ \
ಅ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಎ ಎ  ಋ ಊ  ಎ ಏ  ಎ ಈ  ಎ ಅ  ಋ ಐ  ಏ ಈ  ಏ ಉ  ಉ ಋ\
  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಇ ಇ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಐ ಊ  ಆ ಆ\
 ಊ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಅ ಆ  ಋ ಆ  ಎ ಅ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಉ ಉ  ಈ ಇ  ಈ\
 ಇ  ಈ ಊ  ಈ ಇ  ಏ ಈ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಆ  ಈ ಇ  ಏ ಉ  ಆ ಆ ಉ  ಆ\
 ಆ ಎ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಇ ಆ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  \
ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಅ  ಈ ಇ  \
ಐ ಏ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ ಅ ಊ  ಐ ಎ  ಐ ಏ  ಆ ಅ ಏ  ಆ ಇ ಆ  ಈ\
 ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  \
ಆ ಆ ಊ  ಆ ಆ ಋ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಐ\
 ಎ  ಈ ಇ  ಉ ಋ  ಆ ಅ ಆ  ಆ ಅ ಈ  ಆ ಅ ಈ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ \
ಅ  ಉ ಆ  ಆ ಅ"
.split("  ")])))
